aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/notification/type/base.php
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2014-08-09 12:42:14 +0200
committerMarc Alexander <admin@m-a-styles.de>2014-08-09 12:42:14 +0200
commit6a13f983a4a65483f361a2e3e799199bdd9b3ae3 (patch)
tree36f64a32c241aa7c8d1e1fcffc2ffa8c9b7e19fa /phpBB/phpbb/notification/type/base.php
parentcccd54dde8d2f7733fb44ae6e47f4ec81fa96056 (diff)
downloadforums-6a13f983a4a65483f361a2e3e799199bdd9b3ae3.tar
forums-6a13f983a4a65483f361a2e3e799199bdd9b3ae3.tar.gz
forums-6a13f983a4a65483f361a2e3e799199bdd9b3ae3.tar.bz2
forums-6a13f983a4a65483f361a2e3e799199bdd9b3ae3.tar.xz
forums-6a13f983a4a65483f361a2e3e799199bdd9b3ae3.zip
[ticket/12742] Replace authenticated with authorised
PHPBB3-12742
Diffstat (limited to 'phpBB/phpbb/notification/type/base.php')
-rw-r--r--phpBB/phpbb/notification/type/base.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/phpbb/notification/type/base.php b/phpBB/phpbb/notification/type/base.php
index 18204aaa03..48b368f7f9 100644
--- a/phpBB/phpbb/notification/type/base.php
+++ b/phpBB/phpbb/notification/type/base.php
@@ -535,14 +535,14 @@ abstract class base implements \phpbb\notification\type\type_interface
}
/**
* Get a list of users that are authenticated to receive notifications
*
* @param array $users Array of users that have subscribed to a notification
* @param int $forum_id Forum ID of the forum
* @param array $options Array of notification options
* @return array Array of users that are authenticated recipients
*/
- protected function get_authenticated_recipients($users, $forum_id, $options)
+ protected function get_authorised_recipients($users, $forum_id, $options)
{
if (empty($users))
{
@@ -535,14 +535,14 @@ abstract class base implements \phpbb\notification\type\type_interface
}
/**
- * Get a list of users that are authenticated to receive notifications
+ * Get a list of users that are authorised to receive notifications
*
* @param array $users Array of users that have subscribed to a notification
@@ -535,14 +535,14 @@ abstract class base implements \phpbb\notification\type\type_interface
* @param int $forum_id Forum ID of the forum
* @param array $options Array of notification options
- * @return array Array of users that are authenticated recipients
+ * @return array Array of users that are authorised recipients
*/